pro go_toban, interactive=interactive, $
	nosrsjcl=nosrsjcl, nosrsget=nosrsget, noreformat=noreformat, noobs=noobs, noevn=noevn, nopnt=nopnt, nosfd=nosfd, $
	nosl=nosl, noccd_sunc=noccd_sunc, nosft=nosft, $
	journal=journal, mail=mail, error=error, $
	year=year, st_tim=st_tim0, en_tim=en_tim0, summary_line=summary_line, dsn=dsn, $
	flare2=flare2, srsget=srsget, copy_cmd=copy_cmd, daily_forecast=daily_forecast
;
;+
;NAME:
;	go_toban
;PURPOSE:
;	To allow the SXT toban to (1) call SRSJCL, (2) call SRSGET, 
;	(3) reformat the data, (4) append to the observing log, 
;	(5) to make the event log, (5) to append to the PNT file, and
;	(6) make SFD files, (7) submit the DAILY_FORECAST batch job
;	(8) make SLD and SLS files, (9) update the CCD_SUNC data file 
;	with the center of the sun location, (10) make the SFT files
;RESTRICTIONS:
;	Only run on FLARE1 or FLARE11
;CALLING SEQUENCE:
;	go_toban
;	go_toban, /interactive, /dsn
;	go_toban, /interactive, srsget=2	;to not interfere with AUTO_TOBAN
;	go_toban, /interactive, /flare2		;to not interfere with AUTO_TOBAN
;	go_toban, /nosrsjcl
;	go_toban, /nosrsjcl, /nosrsget
;	go_toban, /journal
;	go_toban, /mail
;OPTIONAL KEYWORD INPUT:
;	interactive	- If set, ask the user which of the "stages" to run
;	nosrsjcl	- If set, do not run the SRSJCL stage
;	nosrsget	- If set, do not run the SRSGET stage
;	noreformat	- If set, do not run the REFORMAT stage
;	noobs		- If set, do not run the OBS stage
;	noevn		- If set, do not run the EVN stage
;	nopnt		- If set, do not run the PNT stage
;	nosfd		- If set, do not run the SFD stage
;	nosl		- If set, do not run the SLS and SLD stage
;	noccd_sunc	- If set, do not run the CCD_SUNC update stage
;	nosft		- If set, do not run the SFT stage
;	journal		- If set, make a journal file.  The file name will
;			  be GO_TOBANyymmdd.hhmmss in the ~ directory.
;	mail		- If set, send error/warning/status mail messages.
;			  See the list below for what types of messages
;	error		- The error status.  Codes less than 100 are from
;			  GET_SIRIUS.
;		                 0 =  successful
;               		 5 =  SRSGET: "jbopen" or similar error 
;                  		 9 =  SRSGET: The user prompt was not what was 
;				     expected after starting to run "srsget"
;				 10 = SRSGET: "srsget" is begin run already
;
;				100 = No ADA files so cannot figure out the
;				      starting time for SRSGET
;				101 = Calculated SRSGET time span is over 
;				      96 hours which should be impossible
;				110 = No file was created after SRSGET
;				120 = The file SRSGET created had less than
;				      60 seconds of data, so no new data available
;				150 = Not enough disk space on any of the listed
;				      disks.
;	year		- Manually define the year since year nibble is not being
;			  defined properly.				
;	st_tim		- The start time for SRSGET.  If not passed, then the
;			  start time is taken as the time of the last available
;			  data in the last ADA file.
;	en_tim		- The end time for SRSGET.  If not passed, then use the
;			  current UT time.
;	summary_line	- A single line summarizing the success of the GO_TOBAN run
;	copy_cmd	- Optionally the command to copy the SRSPAS.NEW file to
;			  SRSPAS.OLD (signifying that data has been processed)
;DESCRIPTION:
;				GO_TOBAN
;
;	1. Optionally run SRSJCL.
;	2. Optionally run SRSGET.  It purges the files in raw telemetry 
;	   disk keeping the last eight files created (purged by creation
;	   date).  The start time is set to the last data available in
;	   the reformatted ADA files.  The end time is set to the current
;	   time.  For the case when there is no new telemetry available,
;	   SRSGET could still return up to 60 seconds of telemetry
;	   (because of the granularity of the SRSGET command).  If this
;	   occurs, that file is deleted and GO_TOBAN will exit.
;	3. Optionally run REFORMAT.  The routine first checks to see that
;	   enough disk space exists.  If not, it goes through a list of 
;	   disks until it finds enough space, or it reaches the end of the
;	   list.  The current list is: /yd3/reformat, /yd1/reformat.  When
;	   the reformatting is finished, it will send a mail message the
;	   the users specified in the "MAIL" keyword input parameter.  This
;	   is set to "sxt" and "morrison" for calls made from AUTO_TOBAN.
;	4. Optionally copy SRSPAS.NEW to SRSPAS.OLD
;	5. Optionally run MK_OBS.  It only makes the weekly OBS file for
;	   the week # of the data that was just reformatted.  The new
;	   data is appended.
;	6. Optionally run MK_EVN.  It only makes the weekly EVN file for
;	   the week # of the data that was just reformatted.  A whole
;	   new file is created.
;	7. Optionally run MK_PNT.  It only makes the weekly PNT file for
;	   the week # of the data that was just reformatted.  The new
;	   data is appended.
;	8. Optionally run MK_SFD.  A separate SFD file is created for each
;	   new SFR file available.
;	9. Optionally submit the DAILY_FORECAST batch job to copy daily
;	   images to various institutions around the country.
;	10. Optionally run MK_SL for SLS and SLD files.  A whole new file is
;	   created.
;	11. Create SFT files
;
;	   Environment 			When they get messages
;	    Variable
;
;	$MAIL_TOBAN_STATUS	* Successful completion of reformating stage
;	$MAIL_TOBAN_ERROR	* SRSGET Error - someone else running SRSGET
;				* No ADA files available to determine start
;				  time for SRSGET
;				* Not enough disk space on a listed disk
;				* No disk space on ANY of the listed disks
;	$MAIL_TOBAN_WARN	* Down to less than 100 megabytes on primary
;				  disk
;				* SRSGET Info - less than 60 sec of new data
;				* SRSGET Info - main frame is off
;				* SRSGET Info - some other SRSGET error
;	$MAIL_TOBAN_DEBUG
;				* Successful completion of all of GO_TOBAN
;HISTORY:
;	Written 14-Oct-92 by M.Morrison using GO_GET_SIRIUS as a start.
;	15-Oct-92 (MDM) - Added MK_PNT "stage"
;	16-Oct-92 (MDM) - Made variable "wid" into a scalar since it
;			  caused problems to MK_EVN
;	20-Oct-92 (MDM) - Added MK_SFD "stage"
;	21-Oct-92 (MDM) - Added jump capbility to only run MK_SFD (goto statement)
;       21-Oct-92 (SLF) - Added spawning of srsjcl on flare1 
;			  (shuto san program to create sirius Temp data)
;			  added informational messages for each stage
;	23-Oct-93 (MDM) - Added jump capability to only build the INFIL array
;			- Added /USEFID to MK_OBS call
;	26-Oct-92 (MDM) - Changed from a program to a procedure
;	 2-Nov-92 (MDM) - Modified so that if NOSRSGET is set and REFORMAT is set, 
;			  then prompt the user for the input file name
;	 3-Nov-92 (MDM) - Modifed 2-Nov patch to use the proper directory name
;			  for flare1 and flare11 use.
;	 5-Nov-92 (MDM) - Modified to prompt the user for the WeekID if
;			  NOREFORMAT is set.
;	19-Nov-92 (MDM) - Added check of error status from GET_SIRIUS.  Stop
;			  GO_TOBAN if there was an error.
;	25-Nov-92 (SLF) - Added auto purge of raw telemetry disk
;			  Increased number of beeps when reformatter completed
;			  Logic to find raw telemtry disk mount name
;			  (may be machine dependent)
;	30-Nov-92 (MDM) - Added the /JOURNAL option
;			- Also printed the options selected 
;	 1-Dec-92 (MDM) - Adjusted the logic of the "nosrsjcl" type keywords
;	 3-Dec-92 (MDM) - Added extra check in SRSGET stage to see that the 
;			  raw telemetry file had at least more than one minute
;			  of data.  This is necessary because if SRSGET was
;			  called a second time when there was no new data, we
;			  will get at least one minute of data.  If there is
;			  less than one minute, then delete the file.
;			- Added check to see that enough disk space exists
;			  for the reformatted data files.
;			- Added MAIL option to send mail after reformatting
;	 8-Dec-92 (MDM) - Added extensive mail message options for monitoring
;			  progress.  The environment variables $MAIL_TOBAN_xxx
;			  were introduced.
;	 8-Dec-92 (MDM) - Added MK_SL stage to make SLS and SLD files (leak
;			  tracking routines).
;	11-Dec-92 (MDM) - Changed the mail message to print out the time range
;			  covered in the new reformatted data
;	14-Dec-92 (MDM) - Changed maximum duration that is alowable from 48
;			  hours to 96 hours (since we can have big gaps over
;			  weekends)
;	 1-Jan-93 (MDM) - Removed number of hours check from GET_SIRIUS
;	 4-Jan-93 (MDM) - Added the YEAR keyword for REFORMAT use
;	 5-Jan-93 (MDM) - Changed the error/warning mail messages some for
;			  GET_SIRIUS stage.
;	 8-Jan-93 (MDM) - Modification to MK_SL stage to check that SFR file
;			  exists first.
;	20-Jan-93 (MDM) - Fixed an error with MK_SL stage.  It was not selecting
;			  the files properly since 8-Jan-93 modification.
;	20-Jan-93 (MDM) - Added ST_TIM and EN_TIM keyword options.  Also added
;			  SUMMARY_LINE
;	26-Jan-93 (MDM) - Fixed up logic for MK_SFD stage.  It was crashing if
;			  no SFD files needed to be made.
;			- Changed format of the SUMMARY_LINE string
;	 2-Feb-93 (MDM) - Changed the "slop" requirement to 125% of raw telemetry
;			  file.  If less than that space is free, go to the backup
;			  disk.  It used to be 110%.
;			- Corrected mail message for case where not enough
;			  disk space is free for reformatting (listed wrong disk)
;	 9-Mar-93 (MDM) - Added /AUTODEL switch to REFORMAT call to delete the
;			  files if they already exist
;			- Changed logic to find the last directory which is
;			  not empty to figure out the reformatted data directory
;	14-Apr-93 (MDM) - Added /DSN option
;			- Changed "df" command to be "df -n" to find raw tlm dir
;	29-May-93 (MDM) - Added update of CCD_SUNC data file with the center of the 
;			  sun location
;			- Added /NOCCD_SUNC switch (and /NOSL since it was missing)
;	10-Aug-93 (MDM) - Modified the way that CCD_SUNC calculation was being done.
;	11-Aug-93 (MDM) - Corrected typo of 10-Aug
;	30-Aug-93 (MDM) - The raw telemetry directory name was not being determined
;			  properly for flare workstations (raw telem files were
;			  not getting purged as a result)
;			- Modified to save 15 raw telem files (instead of 8)
;	30-Sep-93 (MDM) - Corrected typo in the mail message "will" vs "with"
;	 7-Oct-93 (MDM) - Changed to use $DIR_SITE_NEWDATA instead of /yd3/reformat
;	10-Oct-93 (MDM) - Added creation of ATR and ATT (will remove PNT after
;			  confirming ATR/ATT creation is working)
;	11-Oct-93 (MDM) - Corrected error in CCDSUNC option for the case where
;			  no PNT data is available.
;	12-Oct-93 (MDM) - Added call to DAILY_FORECAST to copy 4 forecast images to
;			  remote institutions.
;	14-Oct-93 (MDM) - Modified call to DAILY_FORECAST to keep 20 IDL log files
;	16-Oct-93 (MDM) - Have DAILY_FORCAST called every time - have it figure if
;			  it sould run or not
;	11-Nov-93 (MDM) - Added FLARE2 and SRSGET options so that GO_TOBAN can be
;			  used without interfering with AUTO_TOBAN
;	16-Nov-93 (MDM) - Removed unnecessary code
;	19-Nov-93 (MDM) - Added MK_SFT stage
;	 2-Dec-93 (MDM) - Added COPY_CMD (copy SRSPAS.NEW to SRSPAS.OLD)
;			- Added /DAILY_FORECAST option
;	 8-Dec-93 (MDM) - Make DAILY_FORECAST job be submitted right after
;			  MK_SFD stage
;			- Have alarm at 100 meg or less free (used to
;			  be 50 meg)
;	14-Dec-93 (MDM) - removed MK_PNT from the set of things done
;			- Commented out all references to SRSJCL
;	 3-Mar-94 (MDM) - Changed logic so that it would work for the case
;			  where there are no ADA files in the reformat directory
;			  but they aren't needed anyway because "st_tim0"
;			  is passed in
;       10-May-94 (SLF) - use /noftp switch to idl_batch call (daily_forecast)
;       12-May-94 (SLF) - replace spawn df with look at /etc/fstab
;       10-Jul-94 (SLF) - spawn mk_newdata as background task after SFD 
;       24-Sep-94 (SLF) - rsh mk_newdata and daily_forecast to unburden isaas0 (and run faster?)
;       26-Sep-94 (SLF) - use is_bestnode to select 'best' node for spawned tasks
;        8-oct-94 (SLF) - spawn mk_spd as another background task
;        1-nov-94 (SLF) - spawn mk_newdata on local (it spawns subtasks on others)
;        7-nov-94 (SLF) - use go_batch for mk_newdata
;        9-Dec-94 (SLF) - remove DATE switch for mk_newdata log
;	 6-Mar-95 (MDM) - Execute "COPY_CMD" for the case where less than 35
;			  major frames are copied during SRSGET
;	10-Mar-95 (MDM) - Modified so that SUMMARY_LINE is defined for problem cases
;       11-may-95 (SLF) - submit daily_forecast on isass1
;       10-jun-95 (SLF) - move forecast to isass0 (cant fix isass1 remotly)
;       23-aug-95 (SLF) - use temporary SFC area for SFD (entrance filter failure)
;        9-nov-95 (SLF) - call mk_sfc when mk_sft is run
;       17-nov-95 (SLF) - rm go_batch for mk_spd
;       11-jan-96 (SLF) - change get_sirius call - inhibit TEMP if DSN
;       19-mar-96 (SLF) - reinstated ccd_sunc updates (att instead of pnt)
;       23-mar-96 (SLF) - divided sxt_cen by 4! (prior to entry into ccd_sunc)
;       04-apr-96 (GLS) - reversed the sense of the EW coordinate
;			  (prior to entry into ccd_sunc)
;       22-aug-97 (SLF) - remove /append and /usefid switches in mk_week,'atr'
;       98-08i-05 (PGS) - added switch to test and allow for either isass0 or isass5 operation 
;
;-
;
summary_line = '????'
;;indir = ['/yd3/reformat', '/yd1/reformat']		;the reformatted data directory
indir = [getenv('DIR_SITE_NEWDATA'), getenv('DIR_SITE_NEWDATA2')]	;the reformatted data directories
st_iindir = n_elements(indir)	;start with the last one
repeat begin
    st_iindir = st_iindir - 1
    fff = file_list(indir(st_iindir), 'ada*')
end until ((st_iindir eq 0) or (fff(0) ne ''))
iindir = st_iindir
wid = ' '
error = 0
start_time1 = systime(1)
run_time1 = 0.
run_time2 = 0.
;
;;qsrsjcl   = 1 - keyword_set(nosrsjcl)		;No = 0, Yes = 1
qsrsget   = 1 - keyword_set(nosrsget)
qreformat = 1 - keyword_set(noreformat)
qobs      = 1 - keyword_set(noobs)
qevn      = 1 - keyword_set(noevn)
qpnt      = 1 - keyword_set(nopnt)
qsfd      = 1 - keyword_set(nosfd)
qsl       = 1 - keyword_set(nosl)
qccd_sunc = 1 - keyword_set(noccd_sunc)
qsft      = 1 - keyword_set(nosft)
ans_arr = ['No ', 'Yes']
if (keyword_set(interactive)) then begin
    ;yesnox, 'Run SRSJCL?   ', qsrsjcl, ans_arr(abs(qsrsjcl))	;No = 0, yes = 1
    yesnox, 'Run SRSGET?   ', qsrsget, ans_arr(abs(qsrsget))
    yesnox, 'Run REFORMAT? ', qreformat, ans_arr(abs(qreformat))
    yesnox, 'Run MK_OBS?   ', qobs, ans_arr(abs(qobs))
    yesnox, 'Run MK_EVN?   ', qevn, ans_arr(abs(qevn))
    yesnox, 'Run MK_PNT?   ', qpnt, ans_arr(abs(qpnt))
    yesnox, 'Run MK_SFD?   ', qsfd, ans_arr(abs(qsfd))
    yesnox, 'Run MK_SL?    ', qsl, ans_arr(abs(qsl))
    yesnox, 'Run CCD_SUNC? ', qccd_sunc, ans_arr(abs(qccd_sunc))
    yesnox, 'Run MK_SFT?   ', qsft, ans_arr(abs(qsft))
end
;
if (keyword_set(journal)) then begin		;MDM added 30-Nov-92
    jou_fil = '~/GO_TOBAN' + ex2fid( anytim2ex(!stime) ,/sec)
    if (!journal ne 0) then begin
	print, 'GO_TOBAN: Journal option is used, but a journal file is already open'
	print, 'GO_TOBAN: Closing current journal file'
	tbeep
	journal		;close journal file
    end
    journal, jou_fil
end
;
ans_arr = ['will be NOT run', 'will be run']		;MDM added 30-Nov-92
;print, 'SRSJCL   ', ans_arr(abs(qsrsjcl))
print, 'SRSGET   ', ans_arr(abs(qsrsget))
print, 'REFORMAT ', ans_arr(abs(qreformat))
print, 'MK_OBS   ', ans_arr(abs(qobs))
print, 'MK_EVN   ', ans_arr(abs(qevn))
print, 'MK_PNT   ', ans_arr(abs(qpnt))
print, 'MK_SFD   ', ans_arr(abs(qsfd))
print, 'MK_SL    ', ans_arr(abs(qsl))
print, 'MK_SFT   ', ans_arr(abs(qsft))
;
; slf, add code to find machine dependent raw telemetry mount point
; slf, 12-May-1994 - dont spawn df commnnds, use fstab for raw mount
if (qsrsget) or (qreformat) then begin
   delim=':'						; fstab delimiter
   if (strmid(get_host(), 0, 5) eq 'flare') then delim=' '
   fstab=rd_tfile('/etc/fstab',5,delim=delim)		; read into columns
   raw=where(strpos(fstab(0,*),'raw') ne -1,rcnt)	; raw telem disk
   rawmount='/raw_tlm'					; default
   if rcnt gt 0 then begin				; found, entry 
      rawrec=fstab(*,raw)
      mount=where(strpos(rawrec(1:*),'raw') ne -1, rcnt) ; now find mount
   endif
   if rcnt gt 0 then rawmount=(rawrec(mount+1))(0) else $
      message,/info,"Can't find raw reference in fstab, using default"
   message,/info,'Raw Telemetry Disk is: ' + rawmount
endif

files = file_list(indir, 'ada*')
nfil = n_elements(files)
;
if (qsrsget) then begin
;   --------------- Auto Purge ------------------------------------------
;   slf, 25-nov-1992 - add auto purge of raw telemetry disk
    message,/info,'Purging raw telemetry disk...'
    purgefiles= rawmount + '/v1/9*/????????.????????'
    file_purge,purgefiles,keep=15,/bydate 
;   ----------------------------------------------------------------------

    if (n_elements(st_tim0) eq 0) then begin
	i = nfil-1
	qdone = 0
	while ((not qdone) or (i eq -1)) do begin
	    infil = files(i)
	    rd_fheader, infil, fheader
	    last_data = anytim2ints([fheader.last_time, fheader.last_day])
	    if (last_data.day ne 0) then qdone = 1	;could have a file that is not complete
	    i = i - 1
	end
	if (i eq -1) then begin
	    message = ['There are no good ADA files in '+ arr2str(indir), $
			'so the date/time of the last processed data is not available']
	    print, message
	    if (keyword_set(mail) and (getenv('MAIL_TOBAN_ERROR') ne '')) then mail, message, user='$MAIL_TOBAN_ERROR'
	    print, 'Returning...
	    error = 100
	    return
        end
	st_tim = last_data 
    end else begin
	st_tim = anytim2ints(st_tim0)				;in UT
    end
    cur_tim = anytim2ints(!stime, off=-9*60L*60L)	;JST is 9 hours ahead of UT
    ;
    ;if (n_elements(st_tim0) eq 0) then st_tim = last_data else st_tim = anytim2ints(st_tim0)				;in UT
    if (n_elements(en_tim0) eq 0) then en_tim = cur_tim   else en_tim = anytim2ints(en_tim0)
    ;
    del_hrs = int2secarr(en_tim, st_tim)/60/60
    srsget_duration = ['Start time for requested transfer: ' + fmt_tim(st_tim), $
			'End time for requested transfer:   ' + fmt_tim(en_tim), $
			'SRSGET Time Spanned:               ' + string(del_hrs) + ' hours']
    if (del_hrs gt 96) then begin
	message = ['This is the improper use for GO_TOBAN', $
		'The duration should never be over 96 hours', $
		srsget_duration]
	print, message
	;;if (keyword_set(mail) and (getenv('MAIL_TOBAN_ERROR') ne '')) then mail, message, user='$MAIL_TOBAN_ERROR'
	error = 101
	;;print, 'Returning...'
	;;return
    end
    qok = 1
    ;;yesnox, 'Is this ok? ', qok, 'Yes'	;SLF removed 24-Oct-92
    ;
    if (not qok) then stop, 'Stopping...'
    ;
    ;---------------------------------------------------------------------------------
    ;
    message,/info,'Starting get_sirius phase...'
    dsn=keyword_set(dsn)
    nodsn=1-dsn    
    get_sirius, st_tim, en_tim, error, temp=nodsn, nodsn=nodsn, outfil=rawfil, flare2=flare2, srsget=srsget
    message = ''
    case error of
	0: ;do nothing - success
	9: begin
		message = 'GO_TOBAN: ERROR DURING SRSGET.  Mainframe is probably off'
		mail_to = 'MAIL_TOBAN_WARN'
	    end
	10: begin
	    	message = [message, 'GO_TOBAN: Someone else is running SRSGET', $
	    		'GO_TOBAN: Please terminate other user of SRSGET.']
	    	mail_to = 'MAIL_TOBAN_ERROR'
	    end
	else: begin
		message = 'GO_TOBAN: ERROR DURING SRSGET.  Error = '+string(error)
		mail_to = 'MAIL_TOBAN_WARN'
	    end
    endcase
    if (message ne '') then begin
	print, message
	if (keyword_set(mail) and (getenv(mail_to) ne '')) then mail, message, user='$'+mail_to
	print, 'Returning...'
	summary_line = message(0)
	return
    end

    if (not file_exist(rawfil)) then begin		;MDM added 3-Dec-92
	message = ['GO_TOBAN: ERROR DURING SRSGET - Output file was not created', $
		'and there was no associated error returned from SRSGET']
	print, message
	if (keyword_set(mail) and (getenv('MAIL_TOBAN_ERROR') ne '')) then mail, message, user='$MAIL_TOBAN_ERROR'
	print, 'GO_TOBAN: Returning...
	error = 110
	summary_line = message(0)
	return
    end
    nnn = file_info2(rawfil, finfo)
    nmf = finfo.size/9216		;number of major frames copied
    if (nmf lt 35) then begin				;MDM added 3-Dec-92
	message =  ['GO_TOBAN: No new data.  Only one minute or less of data copied', $
			'Deleting file: ' + rawfil(0) + ' and exiting GO_TOBAN']
	spawn, 'rm -f ' + rawfil(0)
	print, message
	if (keyword_set(mail) and (getenv('MAIL_TOBAN_WARN') ne '')) then mail, message, user='$MAIL_TOBAN_WARN'
	print, 'GO_TOBAN: Returning...
	error = 120
	if (keyword_set(copy_cmd)) then spawn, copy_cmd	   ;Now copy SRSPAS.NEW to SRSPAS.OLD - copied here 6-Mar-95
	summary_line = message(0)
	return
    end
end
;
if ((not qsrsget) and (qreformat)) then begin			;MDM added 2-Nov-92
    ;;dirs = get_subdirs('/flare1_raw_tlm_mount/v1')		;only true for ISASSx machines
    ;;;dirs = get_subdirs('/raw_tlm/v1')				;true for flare1 and flare11 machines
    dirs = get_subdirs(rawmount + '/v1')		; slf, 24-nov-92
    ff = file_list(dirs, '*')
    
    nfile = file_info(ff, finfo)
    for i=0,nfile-1 do print, i, ' -- ', finfo(i).filename, '     ', finfo(i).date, ' ', finfo(i).time, ' ', finfo(i).size
    print, -1, ' == File name to be entered by hand'
    input, 'Enter file number to reformat ', ifil, nfile-1

    rawfil = ' '
    if (ifil eq -1) then begin
	read, 'Enter the full file name (including the path) ', rawfil
	if (not file_exist(rawfil)) then begin
	    print, 'GO_TOBAN: Sorry, this file does not exist ', rawfil
	    print, 'Returning...', string(7b)
	    error = 110
	    return
	end
	nfile = file_info(rawfil, finfo)
    end else begin
	rawfil = ff(ifil)
	finfo = finfo(ifil)
    end
end
;
;---------------------------------------------------------------------------------
;
if (qreformat) then begin
    message,/info,'Checking that diskspace is available'		;added 3-Dec-92
    qok = 0
    while (not qok) do begin
	free = diskfree(indir(iindir))		;megabytes
	need = finfo(0).size/1e+6		;converted to megabytes

	if ((iindir eq st_iindir) and (free lt 100)) then begin
	    message = ['         WARNING   WARNING   WARNING ', $
			'Primary reformating disk ' + indir(iindir) + ' down to less than 100 megabytes']
	    print, message
	    if (keyword_set(mail) and (getenv('MAIL_TOBAN_WARN') ne '')) then mail, message, user='$MAIL_TOBAN_WARN'
	end

	if (need*1.25 gt free) then begin	;allow 25% slop		;since SFD files created
	    iindir = iindir + 1
	    if (iindir ge n_elements(indir)) then begin
		message = ['            URGENT URGENT URGENT         ', $
			'GO_TOBAN: None of the disks listed have space', $
			'Checked the following disks: ' + arr2str(indir), $
			'**** Clean up disk space ***']
		print, message
		if (keyword_set(mail) and (getenv('MAIL_TOBAN_ERROR') ne '')) then mail, message, user='$MAIL_TOBAN_ERROR'
		error = 150
		return
	    end else begin
		message = ['GO_TOBAN: Not enough free space on ' + indir(iindir-1), $
				'Need:        ' + string(need) + ' megabytes', $
				'Amount Free: ' + string(free) + ' megabytes', $
				'Looking to use backup disk: ' + indir(iindir)]
		print, message
		if (keyword_set(mail) and (getenv('MAIL_TOBAN_ERROR') ne '')) then mail, message, user='$MAIL_TOBAN_ERROR'
	    end
	end else begin
	    qok = 1
	end
    end

    message,/info,'Starting reformatting phase...'
    reformat, rawfil, /instr, /att, dir=indir(iindir), fileid=fileid, year=year, /autodel
    prstr,replicate(' ',5)
    tbeep,10
    message,/info,'Reformatting complete, you may access the sfr and spr files.
    prstr,replicate(' ',5)

    rd_roadmap, concat_dir(indir(iindir), 'ada'+fileid), rmap
    nn = n_elements(rmap)
    delt = int2secarr(rmap(nn-1), rmap(0))

    message = ['GO_TOBAN: Reformatting finished', $
		'Input Raw Telemetry File: ' + rawfil, $
		'Output FileID: ' + fileid, $
		'Reformatted data covers from: ' + fmt_tim(rmap(0)) + ' to ' + fmt_tim(rmap(nn-1)), $
		'                               which is ' + string(delt/60/60) + ' hours' ]
    if (n_elements(srsget_duration) ne 0) then message = [message, '  ', srsget_duration]
    end_time = systime(1)
    run_time1 = (end_time-start_time1)/60.
    message = [message, '  ', 'SRSGET and REFORMAT stages took: ' + string(run_time1) + ' minutes to run']
    print, message

    if (keyword_set(mail) and (getenv('MAIL_TOBAN_STATUS') ne '')) then mail, message, user='$MAIL_TOBAN_STATUS'
end else begin
    break_file, files(nfil-1), dsk_log, dir, filnam, ext
    fileid = strmid(filnam, 3, 6) + ext
end
;
;---------------------------------------------------------------------------------
;
if (keyword_set(copy_cmd)) then spawn, copy_cmd		;Now copy SRSPAS.NEW to SRSPAS.OLD
;
;---------------------------------------------------------------------------------
;
start_time2 = systime(1)
;
if (qreformat) then begin
    tim2orbit, fid2ex(fileid), wid=wid
    wid = wid(0)
end else begin
    tim2orbit, !stime, wid=wid0
    input, 'Enter the WeekID ', wid, wid0(0)
end
;
files = file_list(indir, 'ada*')
break_file, files, dsk_log, dir, filnam, ext
fids = strmid(filnam, 3, 6) + ext
tim2orbit, fid2ex(fids), wid=wids
ss = where(wids eq wid)
infil = files(ss)			;has to be at least one
;
if (qobs) then begin
    message,/info,'Observing Log Creation...'
    mk_obs, infil, /append, /usefid
end
;
;---------------------------------------------------------------------------------
;
if (qevn) then begin
    message,/info,'Event File Creation...'
    mk_evn, week=wid
end
;
;---------------------------------------------------------------------------------
;
if (qpnt) then begin
    message,/info,'Pointing File Creation...'
    ;;mk_pnt, infil, /append				;MDM removed 14-Dec-93
    mk_week_file, 'atr', infil
    mk_att, wid						;MDM added 10-Oct-93
end
;
;---------------------------------------------------------------------------------
;
; ----------- define a list of remote hosts for background jobs ---------
nodelist='flare' + ['13','14','15']
; ------------------------------------------------------------------------

if (qsfd) then begin
    message,/info,'SFD File Creation...'
    files1 = file_list(indir, 'sfr*')
    files2 = file_list(indir, 'sfd*')
    if (files2(0) eq '') then begin
	infil2 = files1(n_elements(files1)-1)	;only do the last SFR file made
    end else begin
	break_file, files1, dsk_log, dir, filnam, ext
	fids1 = strmid(filnam, 3, 6) + ext
	break_file, files2, dsk_log, dir, filnam, ext
	fids2 = strmid(filnam, 3, 6) + ext
	last_sfd = fids2(n_elements(fids2)-1)
	ss = where(fids1 eq last_sfd)
	if (ss(0) eq n_elements(files1)-1) then begin
	    infil2 = 'xxx'
	end else begin
	    infil2 = files1(ss(0)+1:*)			;do all SFR files since last SFD
	end
    end
    ;
   
    if (infil2(0) ne 'xxx') then begin
;       ****** use sfc temporary area for input sfc if defined *****
        chktemp = get_logenv('DIR_SXT_SFCTEMP')
        if chktemp ne '' then set_logenv,'DIR_SXT_SFC',chktemp
        box_message,infil2
        sfr=newfiles(/sfr,last=5)          ; only consider last 5 SFRs
        sfd=str_replace(sfr,'sfr','sfd')
        need=where(1-file_exist(sfd),ncnt)
        if ncnt gt 0 then begin
           box_message,["Need to make SFDs: ",sfd(need)]
           for ifil=0,ncnt -1 do $
               mk_sfd,sfr(need(ifil)),outfil=sfd(need(ifil))                 
        endif else begin
           box_message,["all SFDs created"]
        endelse
;	for ifil=0,n_elements(infil2)-1 do mk_sfd, infil2(ifil), '', outfil=str_replace(infil2(ifil), 'sfr', 'sfd')
    end

    cmd = 'nohup ' + getenv('ys') + '/gen/script/idl_batch  mk_newdata ' + getenv('ys') + '/site/logs/mk_newdata.log &'
    
    node=get_host()
;    rsh,is_bestnode(/defnode),cmd

    rsh,node,cmd
    cmd = 'nohup ' + getenv('ys') + '/gen/script/idl_batch  go_mk_spd ' + getenv('ys') + '/site/logs/go_mk_spd.log DATE &'
;   rsh,is_bestnode(nodelist,/remove),cmd,/echo,user='software'

    rsh,node,cmd

end
;
;---------------------------------------------------------------------------------


if (keyword_set(daily_forecast) and (n_elements(rmap) gt 1)) then begin
   CASE 1 OF
      (strmid(get_host(), 0, 6) eq 'isass0'): BEGIN
         cmd = 'nohup ' + getenv('ys') + '/gen/script/idl_batch /noftp  go_forecast ' + getenv('ys') + '/site/logs/forecast.log DATE &'
         rsh,'isass0',cmd,/echo,user='software'
      END   
      (strmid(get_host(), 0, 6) eq 'isass5'): BEGIN
         cmd = 'nohup ' + getenv('SSW') + '/gen/bin/ssw_batch /noftp  go_forecast ' + getenv('ys') + '/site/logs/forecast.log DATE &'
         rsh,'isass5',cmd,/echo,user='software'
      END
      ELSE: Print, 'Error, or go_toban.pro must be modified to call go_forecast.pro' 
   ENDCASE

;   IF (strmid(get_host(), 0, 6) eq 'isass0') THEN BEGIN
;       cmd = 'nohup ' + getenv('ys') + '/gen/script/idl_batch /noftp  go_forecast ' + getenv('ys') + '/site/logs/forecast.log DATE &'
;       rsh,'isass0',cmd,/echo,user='software'
;   ENDIF 
;   IF (strmid(get_host(), 0, 6) eq 'isass5') THEN BEGIN
;       cmd = 'nohup ' + getenv('ys') + '/ssw/gen/bin/ssw_batch /noftp  go_forecast ' + getenv('ys') + '/site/logs/forecast.log DATE &'
;       rsh,'isass5',cmd,/echo,user='software'
;   ENDIF
end


;---------------------------------------------------------------------------------
if (qsl) then begin
    infil3 = str_replace(infil, 'ada', 'sfr')
    sss = where(file_exist(infil3))
    if (sss(0) ne -1) then begin
	infil3 = infil3(sss)
	message,/info,'SLD File Creation...'
	mk_sl, infil3, prefix='sld'

	message,/info,'SLS File Creation...'
	mk_sl, infil3, prefix='sls'
    end
end
    
;---------------------------------------------------------------------------------
;
if (qccd_sunc and (n_elements(st_tim) gt 0)) then begin
   rd_week_file, anytim2ints(st_tim, off=-2*60.*60), !stime, 'ATT',att
   if data_chk(att,/struct) then begin
        cen = round(sxt_cen(att(n_elements(att)-1))/4.)
	cen(0) = 255-cen(0)
	dummy = ccd_sunc(update=cen)
   endif
end

;---------------------------------------------------------------------------------
if (qsft) then begin
    infil3 = str_replace(infil, 'ada', 'sfr')
    sss = where(file_exist(infil3))
    if (sss(0) ne -1) then begin
	infil3 = infil3(sss)
	message,/info,'SFT File Creation...'
	mk_sft, infil3
        mk_sfc,wid,/online,/noconfirm		;slf added 9-nov-95        
    end
end

    
;---------------------------------------------------------------------------------
;
message = 'GO_TOBAN: Finished with all stages'
if (n_elements(srsget_duration) ne 0) then message = [message, '  ', srsget_duration]
end_time = systime(1)
run_time2 = (end_time-start_time2)/60.
message = [message, '  ', 'SRSGET and REFORMAT stages took: ' + string(run_time1) + ' minutes to run', $
			'MK_OBS, MK_EVN, MK_PNT and MK_SFD stages took: ' + string(run_time2) + ' minutes to run', $
			'for a total of ' + string(run_time1+run_time2) + ' minutes']
print, message
if (keyword_set(mail) and (getenv('MAIL_TOBAN_DEBUG') ne '')) then mail, message, user='$MAIL_TOBAN_DEBUG'
;
summary_line = 'SRSGET/REF took: ' + string(run_time1, format='(f7.2)') + ' min, and ' + $
		'OBS, EVN, PNT SFD, and SL stages took: ' + string(run_time2, format='(f7.2)') + ' min'

message,/info,'All stages completed succesfully...
if (keyword_set(journal)) then journal		;close journal file
tbeep,2
end
